use mio::Token;

use crate::command::CommandSetPlayer;
use crate::database::Db;
use crate::password::Password;
use crate::queue::SendQueue;
use crate::{try_option_send_error, try_send_error};

impl CommandSetPlayer {
	/// Set the player's password
	pub fn dispatch_password(&self, args: String, token: Token, db: &mut Db) -> SendQueue {
		let player = try_option_send_error!(token, db.get_connected_player(token));

		if args.is_empty() {
			return (token, "Password can't be empty").into();
		}

		let password = try_send_error!(token, Password::new(args));
		let _ = try_send_error!(token, db.save_password(player.id, &password));

		SendQueue::ok(token)
	}
}
